==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkKdTree.java <==
// java wrapper for vtkKdTree object
//

package vtk;
import vtk.*;

public class vtkKdTree extends vtkLocator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void TimingOn_2();
  public void TimingOn()
    { TimingOn_2(); }

  private native void TimingOff_3();
  public void TimingOff()
    { TimingOff_3(); }

  private native void SetTiming_4(int id0);
  public void SetTiming(int id0)
    { SetTiming_4(id0); }

  private native int GetTiming_5();
  public int GetTiming()
    { return GetTiming_5(); }

  private native void SetMinCells_6(int id0);
  public void SetMinCells(int id0)
    { SetMinCells_6(id0); }

  private native int GetMinCells_7();
  public int GetMinCells()
    { return GetMinCells_7(); }

  private native int GetNumberOfRegionsOrLess_8();
  public int GetNumberOfRegionsOrLess()
    { return GetNumberOfRegionsOrLess_8(); }

  private native void SetNumberOfRegionsOrLess_9(int id0);
  public void SetNumberOfRegionsOrLess(int id0)
    { SetNumberOfRegionsOrLess_9(id0); }

  private native int GetNumberOfRegionsOrMore_10();
  public int GetNumberOfRegionsOrMore()
    { return GetNumberOfRegionsOrMore_10(); }

  private native void SetNumberOfRegionsOrMore_11(int id0);
  public void SetNumberOfRegionsOrMore(int id0)
    { SetNumberOfRegionsOrMore_11(id0); }

  private native double GetFudgeFactor_12();
  public double GetFudgeFactor()
    { return GetFudgeFactor_12(); }

  private native void SetFudgeFactor_13(double id0);
  public void SetFudgeFactor(double id0)
    { SetFudgeFactor_13(id0); }

  private native long GetCuts_14();
  public vtkBSPCuts GetCuts() {
    long temp = GetCuts_14();

    if (temp == 0) return null;
    return (vtkBSPCuts)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCuts_15(vtkBSPCuts id0);
  public void SetCuts(vtkBSPCuts id0)
    { SetCuts_15(id0); }

  private native void OmitXPartitioning_16();
  public void OmitXPartitioning()
    { OmitXPartitioning_16(); }

  private native void OmitYPartitioning_17();
  public void OmitYPartitioning()
    { OmitYPartitioning_17(); }

  private native void OmitZPartitioning_18();
  public void OmitZPartitioning()
    { OmitZPartitioning_18(); }

  private native void OmitXYPartitioning_19();
  public void OmitXYPartitioning()
    { OmitXYPartitioning_19(); }

  private native void OmitYZPartitioning_20();
  public void OmitYZPartitioning()
    { OmitYZPartitioning_20(); }

  private native void OmitZXPartitioning_21();
  public void OmitZXPartitioning()
    { OmitZXPartitioning_21(); }

  private native void OmitNoPartitioning_22();
  public void OmitNoPartitioning()
    { OmitNoPartitioning_22(); }

  private native void SetDataSet_23(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_23(id0); }

  private native void AddDataSet_24(vtkDataSet id0);
  public void AddDataSet(vtkDataSet id0)
    { AddDataSet_24(id0); }

  private native void RemoveDataSet_25(int id0);
  public void RemoveDataSet(int id0)
    { RemoveDataSet_25(id0); }

  private native void RemoveDataSet_26(vtkDataSet id0);
  public void RemoveDataSet(vtkDataSet id0)
    { RemoveDataSet_26(id0); }

  private native void RemoveAllDataSets_27();
  public void RemoveAllDataSets()
    { RemoveAllDataSets_27(); }

  private native int GetNumberOfDataSets_28();
  public int GetNumberOfDataSets()
    { return GetNumberOfDataSets_28(); }

  private native long GetDataSet_29(int id0);
  public vtkDataSet GetDataSet(int id0) {
    long temp = GetDataSet_29(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSet_30();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_30();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSets_31();
  public vtkDataSetCollection GetDataSets() {
    long temp = GetDataSets_31();

    if (temp == 0) return null;
    return (vtkDataSetCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetDataSetIndex_32(vtkDataSet id0);
  public int GetDataSetIndex(vtkDataSet id0)
    { return GetDataSetIndex_32(id0); }

  private native int GetNumberOfRegions_33();
  public int GetNumberOfRegions()
    { return GetNumberOfRegions_33(); }

  private native void GetRegionBounds_34(int id0,double id1[]);
  public void GetRegionBounds(int id0,double id1[])
    { GetRegionBounds_34(id0,id1); }

  private native void GetRegionDataBounds_35(int id0,double id1[]);
  public void GetRegionDataBounds(int id0,double id1[])
    { GetRegionDataBounds_35(id0,id1); }

  private native void PrintTree_36();
  public void PrintTree()
    { PrintTree_36(); }

  private native void PrintVerboseTree_37();
  public void PrintVerboseTree()
    { PrintVerboseTree_37(); }

  private native void PrintRegion_38(int id0);
  public void PrintRegion(int id0)
    { PrintRegion_38(id0); }

  private native void CreateCellLists_39();
  public void CreateCellLists()
    { CreateCellLists_39(); }

  private native void SetIncludeRegionBoundaryCells_40(int id0);
  public void SetIncludeRegionBoundaryCells(int id0)
    { SetIncludeRegionBoundaryCells_40(id0); }

  private native int GetIncludeRegionBoundaryCells_41();
  public int GetIncludeRegionBoundaryCells()
    { return GetIncludeRegionBoundaryCells_41(); }

  private native void IncludeRegionBoundaryCellsOn_42();
  public void IncludeRegionBoundaryCellsOn()
    { IncludeRegionBoundaryCellsOn_42(); }

  private native void IncludeRegionBoundaryCellsOff_43();
  public void IncludeRegionBoundaryCellsOff()
    { IncludeRegionBoundaryCellsOff_43(); }

  private native void DeleteCellLists_44();
  public void DeleteCellLists()
    { DeleteCellLists_44(); }

  private native long GetCellList_45(int id0);
  public vtkIdList GetCellList(int id0) {
    long temp = GetCellList_45(id0);

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetBoundaryCellList_46(int id0);
  public vtkIdList GetBoundaryCellList(int id0) {
    long temp = GetBoundaryCellList_46(id0);

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellLists_47(vtkIntArray id0,int id1,vtkIdList id2,vtkIdList id3);
  public int GetCellLists(vtkIntArray id0,int id1,vtkIdList id2,vtkIdList id3)
    { return GetCellLists_47(id0,id1,id2,id3); }

  private native int GetCellLists_48(vtkIntArray id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3);
  public int GetCellLists(vtkIntArray id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3)
    { return GetCellLists_48(id0,id1,id2,id3); }

  private native int GetCellLists_49(vtkIntArray id0,vtkIdList id1,vtkIdList id2);
  public int GetCellLists(vtkIntArray id0,vtkIdList id1,vtkIdList id2)
    { return GetCellLists_49(id0,id1,id2); }

  private native int GetRegionContainingCell_50(vtkDataSet id0,int id1);
  public int GetRegionContainingCell(vtkDataSet id0,int id1)
    { return GetRegionContainingCell_50(id0,id1); }

  private native int GetRegionContainingCell_51(int id0,int id1);
  public int GetRegionContainingCell(int id0,int id1)
    { return GetRegionContainingCell_51(id0,id1); }

  private native int GetRegionContainingCell_52(int id0);
  public int GetRegionContainingCell(int id0)
    { return GetRegionContainingCell_52(id0); }

  private native int GetRegionContainingPoint_53(double id0,double id1,double id2);
  public int GetRegionContainingPoint(double id0,double id1,double id2)
    { return GetRegionContainingPoint_53(id0,id1,id2); }

  private native void BuildLocator_54();
  public void BuildLocator()
    { BuildLocator_54(); }

  private native int ViewOrderAllRegionsInDirection_55(double id0[],vtkIntArray id1);
  public int ViewOrderAllRegionsInDirection(double id0[],vtkIntArray id1)
    { return ViewOrderAllRegionsInDirection_55(id0,id1); }

  private native int ViewOrderRegionsInDirection_56(vtkIntArray id0,double id1[],vtkIntArray id2);
  public int ViewOrderRegionsInDirection(vtkIntArray id0,double id1[],vtkIntArray id2)
    { return ViewOrderRegionsInDirection_56(id0,id1,id2); }

  private native int ViewOrderAllRegionsFromPosition_57(double id0[],vtkIntArray id1);
  public int ViewOrderAllRegionsFromPosition(double id0[],vtkIntArray id1)
    { return ViewOrderAllRegionsFromPosition_57(id0,id1); }

  private native int ViewOrderRegionsFromPosition_58(vtkIntArray id0,double id1[],vtkIntArray id2);
  public int ViewOrderRegionsFromPosition(vtkIntArray id0,double id1[],vtkIntArray id2)
    { return ViewOrderRegionsFromPosition_58(id0,id1,id2); }

  private native void BuildLocatorFromPoints_59(vtkPointSet id0);
  public void BuildLocatorFromPoints(vtkPointSet id0)
    { BuildLocatorFromPoints_59(id0); }

  private native void BuildLocatorFromPoints_60(vtkPoints id0);
  public void BuildLocatorFromPoints(vtkPoints id0)
    { BuildLocatorFromPoints_60(id0); }

  private native long BuildMapForDuplicatePoints_61(double id0);
  public vtkIdTypeArray BuildMapForDuplicatePoints(double id0) {
    long temp = BuildMapForDuplicatePoints_61(id0);

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int FindPoint_62(double id0,double id1,double id2);
  public int FindPoint(double id0,double id1,double id2)
    { return FindPoint_62(id0,id1,id2); }

  private native void FindPointsWithinRadius_63(double id0,double id1[],vtkIdList id2);
  public void FindPointsWithinRadius(double id0,double id1[],vtkIdList id2)
    { FindPointsWithinRadius_63(id0,id1,id2); }

  private native void FindClosestNPoints_64(int id0,double id1[],vtkIdList id2);
  public void FindClosestNPoints(int id0,double id1[],vtkIdList id2)
    { FindClosestNPoints_64(id0,id1,id2); }

  private native long GetPointsInRegion_65(int id0);
  public vtkIdTypeArray GetPointsInRegion(int id0) {
    long temp = GetPointsInRegion_65(id0);

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void FreeSearchStructure_66();
  public void FreeSearchStructure()
    { FreeSearchStructure_66(); }

  private native void GenerateRepresentation_67(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_67(id0,id1); }

  private native void GenerateRepresentationUsingDataBoundsOn_68();
  public void GenerateRepresentationUsingDataBoundsOn()
    { GenerateRepresentationUsingDataBoundsOn_68(); }

  private native void GenerateRepresentationUsingDataBoundsOff_69();
  public void GenerateRepresentationUsingDataBoundsOff()
    { GenerateRepresentationUsingDataBoundsOff_69(); }

  private native void SetGenerateRepresentationUsingDataBounds_70(int id0);
  public void SetGenerateRepresentationUsingDataBounds(int id0)
    { SetGenerateRepresentationUsingDataBounds_70(id0); }

  private native int GetGenerateRepresentationUsingDataBounds_71();
  public int GetGenerateRepresentationUsingDataBounds()
    { return GetGenerateRepresentationUsingDataBounds_71(); }

  private native int NewGeometry_72();
  public int NewGeometry()
    { return NewGeometry_72(); }

  private native void InvalidateGeometry_73();
  public void InvalidateGeometry()
    { InvalidateGeometry_73(); }

  private native long CopyTree_74(vtkKdNode id0);
  public vtkKdNode CopyTree(vtkKdNode id0) {
    long temp = CopyTree_74(id0);

    if (temp == 0) return null;
    return (vtkKdNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkKdTree() { super(); }

  public vtkKdTree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkKdTree.java <==
// java wrapper for vtkKdTree object
//

package vtk;
import vtk.*;

public class vtkKdTree extends vtkLocator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void TimingOn_2();
  public void TimingOn()
    { TimingOn_2(); }

  private native void TimingOff_3();
  public void TimingOff()
    { TimingOff_3(); }

  private native void SetTiming_4(int id0);
  public void SetTiming(int id0)
    { SetTiming_4(id0); }

  private native int GetTiming_5();
  public int GetTiming()
    { return GetTiming_5(); }

  private native void SetMinCells_6(int id0);
  public void SetMinCells(int id0)
    { SetMinCells_6(id0); }

  private native int GetMinCells_7();
  public int GetMinCells()
    { return GetMinCells_7(); }

  private native int GetNumberOfRegionsOrLess_8();
  public int GetNumberOfRegionsOrLess()
    { return GetNumberOfRegionsOrLess_8(); }

  private native void SetNumberOfRegionsOrLess_9(int id0);
  public void SetNumberOfRegionsOrLess(int id0)
    { SetNumberOfRegionsOrLess_9(id0); }

  private native int GetNumberOfRegionsOrMore_10();
  public int GetNumberOfRegionsOrMore()
    { return GetNumberOfRegionsOrMore_10(); }

  private native void SetNumberOfRegionsOrMore_11(int id0);
  public void SetNumberOfRegionsOrMore(int id0)
    { SetNumberOfRegionsOrMore_11(id0); }

  private native double GetFudgeFactor_12();
  public double GetFudgeFactor()
    { return GetFudgeFactor_12(); }

  private native void SetFudgeFactor_13(double id0);
  public void SetFudgeFactor(double id0)
    { SetFudgeFactor_13(id0); }

  private native long GetCuts_14();
  public vtkBSPCuts GetCuts() {
    long temp = GetCuts_14();

    if (temp == 0) return null;
    return (vtkBSPCuts)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCuts_15(vtkBSPCuts id0);
  public void SetCuts(vtkBSPCuts id0)
    { SetCuts_15(id0); }

  private native void OmitXPartitioning_16();
  public void OmitXPartitioning()
    { OmitXPartitioning_16(); }

  private native void OmitYPartitioning_17();
  public void OmitYPartitioning()
    { OmitYPartitioning_17(); }

  private native void OmitZPartitioning_18();
  public void OmitZPartitioning()
    { OmitZPartitioning_18(); }

  private native void OmitXYPartitioning_19();
  public void OmitXYPartitioning()
    { OmitXYPartitioning_19(); }

  private native void OmitYZPartitioning_20();
  public void OmitYZPartitioning()
    { OmitYZPartitioning_20(); }

  private native void OmitZXPartitioning_21();
  public void OmitZXPartitioning()
    { OmitZXPartitioning_21(); }

  private native void OmitNoPartitioning_22();
  public void OmitNoPartitioning()
    { OmitNoPartitioning_22(); }

  private native void SetDataSet_23(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_23(id0); }

  private native void AddDataSet_24(vtkDataSet id0);
  public void AddDataSet(vtkDataSet id0)
    { AddDataSet_24(id0); }

  private native void RemoveDataSet_25(int id0);
  public void RemoveDataSet(int id0)
    { RemoveDataSet_25(id0); }

  private native void RemoveDataSet_26(vtkDataSet id0);
  public void RemoveDataSet(vtkDataSet id0)
    { RemoveDataSet_26(id0); }

  private native void RemoveAllDataSets_27();
  public void RemoveAllDataSets()
    { RemoveAllDataSets_27(); }

  private native int GetNumberOfDataSets_28();
  public int GetNumberOfDataSets()
    { return GetNumberOfDataSets_28(); }

  private native long GetDataSet_29(int id0);
  public vtkDataSet GetDataSet(int id0) {
    long temp = GetDataSet_29(id0);

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSet_30();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_30();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetDataSets_31();
  public vtkDataSetCollection GetDataSets() {
    long temp = GetDataSets_31();

    if (temp == 0) return null;
    return (vtkDataSetCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetDataSetIndex_32(vtkDataSet id0);
  public int GetDataSetIndex(vtkDataSet id0)
    { return GetDataSetIndex_32(id0); }

  private native int GetNumberOfRegions_33();
  public int GetNumberOfRegions()
    { return GetNumberOfRegions_33(); }

  private native void GetRegionBounds_34(int id0,double id1[]);
  public void GetRegionBounds(int id0,double id1[])
    { GetRegionBounds_34(id0,id1); }

  private native void GetRegionDataBounds_35(int id0,double id1[]);
  public void GetRegionDataBounds(int id0,double id1[])
    { GetRegionDataBounds_35(id0,id1); }

  private native void PrintTree_36();
  public void PrintTree()
    { PrintTree_36(); }

  private native void PrintVerboseTree_37();
  public void PrintVerboseTree()
    { PrintVerboseTree_37(); }

  private native void PrintRegion_38(int id0);
  public void PrintRegion(int id0)
    { PrintRegion_38(id0); }

  private native void CreateCellLists_39();
  public void CreateCellLists()
    { CreateCellLists_39(); }

  private native void SetIncludeRegionBoundaryCells_40(int id0);
  public void SetIncludeRegionBoundaryCells(int id0)
    { SetIncludeRegionBoundaryCells_40(id0); }

  private native int GetIncludeRegionBoundaryCells_41();
  public int GetIncludeRegionBoundaryCells()
    { return GetIncludeRegionBoundaryCells_41(); }

  private native void IncludeRegionBoundaryCellsOn_42();
  public void IncludeRegionBoundaryCellsOn()
    { IncludeRegionBoundaryCellsOn_42(); }

  private native void IncludeRegionBoundaryCellsOff_43();
  public void IncludeRegionBoundaryCellsOff()
    { IncludeRegionBoundaryCellsOff_43(); }

  private native void DeleteCellLists_44();
  public void DeleteCellLists()
    { DeleteCellLists_44(); }

  private native long GetCellList_45(int id0);
  public vtkIdList GetCellList(int id0) {
    long temp = GetCellList_45(id0);

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetBoundaryCellList_46(int id0);
  public vtkIdList GetBoundaryCellList(int id0) {
    long temp = GetBoundaryCellList_46(id0);

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellLists_47(vtkIntArray id0,int id1,vtkIdList id2,vtkIdList id3);
  public int GetCellLists(vtkIntArray id0,int id1,vtkIdList id2,vtkIdList id3)
    { return GetCellLists_47(id0,id1,id2,id3); }

  private native int GetCellLists_48(vtkIntArray id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3);
  public int GetCellLists(vtkIntArray id0,vtkDataSet id1,vtkIdList id2,vtkIdList id3)
    { return GetCellLists_48(id0,id1,id2,id3); }

  private native int GetCellLists_49(vtkIntArray id0,vtkIdList id1,vtkIdList id2);
  public int GetCellLists(vtkIntArray id0,vtkIdList id1,vtkIdList id2)
    { return GetCellLists_49(id0,id1,id2); }

  private native int GetRegionContainingCell_50(vtkDataSet id0,int id1);
  public int GetRegionContainingCell(vtkDataSet id0,int id1)
    { return GetRegionContainingCell_50(id0,id1); }

  private native int GetRegionContainingCell_51(int id0,int id1);
  public int GetRegionContainingCell(int id0,int id1)
    { return GetRegionContainingCell_51(id0,id1); }

  private native int GetRegionContainingCell_52(int id0);
  public int GetRegionContainingCell(int id0)
    { return GetRegionContainingCell_52(id0); }

  private native int GetRegionContainingPoint_53(double id0,double id1,double id2);
  public int GetRegionContainingPoint(double id0,double id1,double id2)
    { return GetRegionContainingPoint_53(id0,id1,id2); }

  private native void BuildLocator_54();
  public void BuildLocator()
    { BuildLocator_54(); }

  private native int ViewOrderAllRegionsInDirection_55(double id0[],vtkIntArray id1);
  public int ViewOrderAllRegionsInDirection(double id0[],vtkIntArray id1)
    { return ViewOrderAllRegionsInDirection_55(id0,id1); }

  private native int ViewOrderRegionsInDirection_56(vtkIntArray id0,double id1[],vtkIntArray id2);
  public int ViewOrderRegionsInDirection(vtkIntArray id0,double id1[],vtkIntArray id2)
    { return ViewOrderRegionsInDirection_56(id0,id1,id2); }

  private native int ViewOrderAllRegionsFromPosition_57(double id0[],vtkIntArray id1);
  public int ViewOrderAllRegionsFromPosition(double id0[],vtkIntArray id1)
    { return ViewOrderAllRegionsFromPosition_57(id0,id1); }

  private native int ViewOrderRegionsFromPosition_58(vtkIntArray id0,double id1[],vtkIntArray id2);
  public int ViewOrderRegionsFromPosition(vtkIntArray id0,double id1[],vtkIntArray id2)
    { return ViewOrderRegionsFromPosition_58(id0,id1,id2); }

  private native void BuildLocatorFromPoints_59(vtkPointSet id0);
  public void BuildLocatorFromPoints(vtkPointSet id0)
    { BuildLocatorFromPoints_59(id0); }

  private native void BuildLocatorFromPoints_60(vtkPoints id0);
  public void BuildLocatorFromPoints(vtkPoints id0)
    { BuildLocatorFromPoints_60(id0); }

  private native long BuildMapForDuplicatePoints_61(double id0);
  public vtkIdTypeArray BuildMapForDuplicatePoints(double id0) {
    long temp = BuildMapForDuplicatePoints_61(id0);

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int FindPoint_62(double id0,double id1,double id2);
  public int FindPoint(double id0,double id1,double id2)
    { return FindPoint_62(id0,id1,id2); }

  private native void FindPointsWithinRadius_63(double id0,double id1[],vtkIdList id2);
  public void FindPointsWithinRadius(double id0,double id1[],vtkIdList id2)
    { FindPointsWithinRadius_63(id0,id1,id2); }

  private native void FindClosestNPoints_64(int id0,double id1[],vtkIdList id2);
  public void FindClosestNPoints(int id0,double id1[],vtkIdList id2)
    { FindClosestNPoints_64(id0,id1,id2); }

  private native long GetPointsInRegion_65(int id0);
  public vtkIdTypeArray GetPointsInRegion(int id0) {
    long temp = GetPointsInRegion_65(id0);

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void FreeSearchStructure_66();
  public void FreeSearchStructure()
    { FreeSearchStructure_66(); }

  private native void GenerateRepresentation_67(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_67(id0,id1); }

  private native void GenerateRepresentationUsingDataBoundsOn_68();
  public void GenerateRepresentationUsingDataBoundsOn()
    { GenerateRepresentationUsingDataBoundsOn_68(); }

  private native void GenerateRepresentationUsingDataBoundsOff_69();
  public void GenerateRepresentationUsingDataBoundsOff()
    { GenerateRepresentationUsingDataBoundsOff_69(); }

  private native void SetGenerateRepresentationUsingDataBounds_70(int id0);
  public void SetGenerateRepresentationUsingDataBounds(int id0)
    { SetGenerateRepresentationUsingDataBounds_70(id0); }

  private native int GetGenerateRepresentationUsingDataBounds_71();
  public int GetGenerateRepresentationUsingDataBounds()
    { return GetGenerateRepresentationUsingDataBounds_71(); }

  private native int NewGeometry_72();
  public int NewGeometry()
    { return NewGeometry_72(); }

  private native void InvalidateGeometry_73();
  public void InvalidateGeometry()
    { InvalidateGeometry_73(); }

  private native long CopyTree_74(vtkKdNode id0);
  public vtkKdNode CopyTree(vtkKdNode id0) {
    long temp = CopyTree_74(id0);

    if (temp == 0) return null;
    return (vtkKdNode)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkKdTree() { super(); }

  public vtkKdTree(long id) { super(id); }
  public native long   VTKInit();

}
